camelot.camelot.empty_project.main

Package camelot :: Package camelot :: Package empty_project :: Module main |
[hide private]
[frames] | no frames]

# Module main

source code

Functions | [hide private]
main() | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.main')`
| QT_MAJOR_VERSION = `float('.'.join(str(QtCore.QT_VERSION_STR).s`...``

Variables Details | [hide private]

  ### QT_MAJOR_VERSION Value:
      float('.'.join(str(QtCore.QT_VERSION_STR).split('.') [0: 2]))